# About

Scoutr was built as a means to provide a simple way to put an API in front of a NoSQL backend and ensure full
role-based access control (RBAC) integration with audit logging.

A Go implementation is available at [scoutr-go](https://github.com/MichaelPalmer1/scoutr-go).
